@@ -1,4 +1,4 @@
-"panelmatch" <- function(donnee,col.p,col.j,firstvar,alpha=0.05,coord=c(1,2),scale.unit=TRUE,nbsimul=500,nbchoix=NULL,bloc=NULL,name.bloc=NULL,centerbypanelist=TRUE,scalebypanelist=FALSE,name.panelist=FALSE,cex=1,color=NULL,hierar=NULL){
+"panelmatch" <- function(donnee,col.p,col.j,firstvar,alpha=0.05,coord=c(1,2),scale.unit=TRUE,nbsimul=500,nbchoix=NULL,centerbypanelist=TRUE,scalebypanelist=FALSE,name.panelist=FALSE,cex=1,color=NULL,hierar=NULL){
 
 hotelling <- function(d1,d2,n1=nrow(d1),n2=nrow(d2)){
     k <- ncol(d1)
@@ -55,22 +55,21 @@ hdil <- function(X) {
 }
 
 
-hweight <- function (X, H) {
-    nbnivh <- length(H)
-    nivo <- htabdes(H)
-    cw <- rep(1, ncol(X))
+hweight <- function (X, H, type = rep("s", length(H[[1]]))) {
+    #Je cre un Hq dans la cas o il y a des qualitatives
+    Hq=H
+    #initialisation de la pondration 
+    niv1 = MFA(X, group = H[[1]], type = type, graph = FALSE)
+    cw <- niv1$call$col.w
+    Hq[[1]] = niv1$call$group.mod
+    Hinter=htabdes(Hq)
+    nbnivh <- length(Hq)
     cw.partiel <- H
-    for (n in 1:nbnivh) {
-    Xinter <- ktab.data.frame(X,nivo[[n]],w.col=cw)
-        sepan <- sepan(Xinter)
-        nbloc <- length(sepan$blo)
-    rank.fac <- factor(rep(1:nbloc, sepan$rank))
-        cwinter <- NULL
-    for (i in 1:nbloc) {
-            cwinter <- c(cwinter, rep(1/sepan$Eig[rank.fac == i][1],sepan$blo[i]))
-    }
-        cw <- cw * cwinter
-        cw.partiel[[n]] <- cw
+    cw.partiel[[1]] <- cw
+    for (n in 2:nbnivh) {
+      niv2 = MFA(niv1$call$XTDC,group=Hinter[[n]], type = c(rep("c",length(Hinter[[n]]))), weight.col.mfa = cw, graph=FALSE)
+      cw = niv2$call$col.w*cw
+      cw.partiel[[n]] <- cw
     }
     return(cw.partiel)
 }
@@ -92,21 +91,22 @@ hweight <- function (X, H) {
  nbpanel=length(donnee)
  labprod = levels(as.factor(donnee[[1]][,col.p]))
  nbprod=length(labprod)
- for (bloc in 1:length(donnee)) {
-   nvar=c(nvar,ncol(donnee[[bloc]])-firstvar+1)
+ for (group in 1:length(donnee)) {
+   nvar=c(nvar,ncol(donnee[[group]])-firstvar+1)
  }
  if (length(hierar)!=0) nvar=hierar[[1]]
- if (length(hierar)==0) hierar=list(nvar)
- for (bloc in 1:nbpanel){
-#    aux <- search.desc(donnee[[bloc]],level=level.search.desc,col.j=col.j,col.p=col.p,firstvar=firstvar) # pas de slection car sinon la hirarchie est  revoir
-    aux = scalebypanelist(donnee[[bloc]],center=centerbypanelist,scale=scalebypanelist,col.j=col.j,col.p=col.p,firstvar=firstvar)
+ if (length(hierar)==0) hierar=nvar
+ if (!is.list(hierar)) hierar = list(hierar,rep(1,length(hierar)))
+ for (group in 1:nbpanel){
+#    aux <- search.desc(donnee[[group]],level=level.search.desc,col.j=col.j,col.p=col.p,firstvar=firstvar) # pas de slection car sinon la hirarchie est  revoir
+    aux = scalebypanelist(donnee[[group]],center=centerbypanelist,scale=scalebypanelist,col.j=col.j,col.p=col.p,firstvar=firstvar)
     nbjuge=c(nbjuge,nrow(aux)/nbprod-1)
     numligne=c(numligne,nrow(aux)-nbprod)
-    namegr=c(namegr,paste("P",bloc,sep=""))
-    namevar=c(namevar,paste("P",bloc,"_",colnames(donnee[[bloc]])[-(1:(firstvar-1))],sep=""))
-    nvarpanel=c(nvarpanel,ncol(donnee[[bloc]])-firstvar+1)
-    if (bloc==1) aamoy = aux[1:nbprod,]
-    if (bloc!=1) aamoy = cbind(aamoy,aux[1:nbprod,-(1:2)])
+    namegr=c(namegr,paste("P",group,sep=""))
+    namevar=c(namevar,paste("P",group,"_",colnames(donnee[[group]])[-(1:(firstvar-1))],sep=""))
+    nvarpanel=c(nvarpanel,ncol(donnee[[group]])-firstvar+1)
+    if (group==1) aamoy = aux[1:nbprod,]
+    if (group!=1) aamoy = cbind(aamoy,aux[1:nbprod,-(1:2)])
  }
  rownames(aamoy)=aamoy[,2]
  tab=aamoy[,-(1:2)]
@@ -116,7 +116,7 @@ hweight <- function (X, H) {
  ecart <- matrix(apply(tab,2,var),nrow=nrow(tab),ncol=ncol(tab),byrow=TRUE)*(nrow(tab)-1)/nrow(tab)
  if (scale.unit==TRUE) tab <- tab / sqrt(ecart)
  aamoy = tab
- resafmh=hmfa(as.data.frame(aamoy),hierar,coord=coord)
+ resafmh=HMFA(as.data.frame(aamoy),H=hierar, type = rep("c", length(hierar[[1]])),graph=FALSE)
  dilat = hdil(hierar)
 
 ##
@@ -125,14 +125,14 @@ for (j in 1:length(hierar)){
 }
 poids = hweight(aamoy,hierar)
 
-for (bloc in 1:nbpanel){
-#    aux <- search.desc(donnee[[bloc]],level=level.search.desc,col.j=col.j,col.p=col.p,firstvar=firstvar) # pas de slection car sinon la hirarchie est  revoir
-    aux = scalebypanelist(donnee[[bloc]],center=centerbypanelist,scale=scalebypanelist,col.j=col.j,col.p=col.p,firstvar=firstvar)
+for (group in 1:nbpanel){
+#    aux <- search.desc(donnee[[group]],level=level.search.desc,col.j=col.j,col.p=col.p,firstvar=firstvar) # pas de slection car sinon la hirarchie est  revoir
+    aux = scalebypanelist(donnee[[group]],center=centerbypanelist,scale=scalebypanelist,col.j=col.j,col.p=col.p,firstvar=firstvar)
     tab=aux[1:nbprod,-(1:2)]
     moy <- matrix(apply(tab,2,mean),nrow=nrow(tab),ncol=ncol(tab),byrow=TRUE)
     ecart <- matrix(apply(tab,2,var),nrow=nrow(tab),ncol=ncol(tab),byrow=TRUE)*(nrow(tab)-1)/nrow(tab)
     aux=aux[-(1:nbprod),]
-    aux2 = cbind.data.frame(paste(namegr[bloc],aux[,1],sep="_"),aux[,2])
+    aux2 = cbind.data.frame(paste(namegr[group],aux[,1],sep="_"),aux[,2])
     aux = aux[,-(1:2)]
     tab.illu = aux
     moy <- matrix(rep(moy[1,],nrow(tab.illu)),nrow=nrow(tab.illu),ncol=ncol(tab.illu),byrow=TRUE)
@@ -141,61 +141,59 @@ for (bloc in 1:nbpanel){
     if (scale.unit==TRUE) tab.illu <- tab.illu/sqrt(ecart.illu)
     aux = tab.illu
     names(aux)=NULL
-    if (bloc == 1) aux3=cbind.data.frame(aux,matrix(0,nrow(aux),sum(nvarpanel[(bloc+1):length(nvarpanel)])))
-    if ((bloc >1) & (bloc != nbpanel)) aux3 = data.frame(matrix(0,nrow(aux),sum(nvarpanel[1:(bloc-1)])),aux,matrix(0,nrow(aux),sum(nvarpanel[(bloc+1):length(nvarpanel)])))
-    if (bloc==nbpanel) aux3 = cbind.data.frame(matrix(0,nrow(aux),sum(nvarpanel[1:(bloc-1)])),aux)
+    if (group == 1) aux3=cbind.data.frame(aux,matrix(0,nrow(aux),sum(nvarpanel[(group+1):length(nvarpanel)])))
+    if ((group >1) & (group != nbpanel)) aux3 = data.frame(matrix(0,nrow(aux),sum(nvarpanel[1:(group-1)])),aux,matrix(0,nrow(aux),sum(nvarpanel[(group+1):length(nvarpanel)])))
+    if (group==nbpanel) aux3 = cbind.data.frame(matrix(0,nrow(aux),sum(nvarpanel[1:(group-1)])),aux)
     colnames(aux3)=namevar
 #    formule <- as.matrix(aux3) %*% diag(poids[[nivpanel]]) %*% t(aamoy) %*% diag(rep((1/nbprod),nbprod))
     formule <- as.matrix(aux3) %*% diag(poids[[length(hierar)]]) %*% t(aamoy) %*% diag(rep((1/nbprod),nbprod))
-    formule <- formule %*% as.matrix(resafmh$hmfa$li)[,1:max(coord)] %*% diag(1/resafmh$hmfa$eig[1:max(coord)]) * dilat[[nivpanel]][bloc]
-    indivbloc = cbind.data.frame(formule,aux2[,c(2,1)])
-    if (bloc !=1) indiv = rbind(indiv,indivbloc)
-    if (bloc ==1) indiv = indivbloc
+    formule <- formule %*% as.matrix(resafmh$ind$coord)[,1:max(coord)] %*% diag(1/resafmh$eig[1:max(coord),1]) * dilat[[nivpanel]][group]
+    indivgroup = cbind.data.frame(formule,aux2[,c(2,1)])
+    if (group !=1) indiv = rbind(indiv,indivgroup)
+    if (group ==1) indiv = indivgroup
 }
     colnames(indiv)[(ncol(indiv)-1):ncol(indiv)]=c("Product","Panelist")
 
  comp.simul=list()
- for (bloc in 1:nbpanel){
+ for (group in 1:nbpanel){
    auxi = cbind.data.frame(indiv[1:nbprod,-((ncol(indiv)-1):ncol(indiv))],rownames(aamoy),rep(0,nbprod))
    colnames(auxi)[(ncol(indiv)-1):ncol(indiv)]=c("Product","Panelist")
    aa1=list()
-   aa1$moyen=rbind.data.frame(auxi,indiv[(sum(numligne[1:bloc])-numligne[bloc] +1):(sum(numligne[1:bloc])),])
+   aa1$moyen=rbind.data.frame(auxi,indiv[(sum(numligne[1:group])-numligne[group] +1):(sum(numligne[1:group])),])
    aa1$moyen[,ncol(aa1$moyen)]=as.factor(aa1$moyen[,ncol(aa1$moyen)])
-   simul <- simulation(aa1, nbbloc = 1,nbsimul=nbsimul,nbchoix=nbchoix)
-   if (bloc==1) auxil = simul$moy$simul[,-ncol(simul$moy$simul)]
-   if (bloc!=1) auxil=cbind(auxil,simul$moy$simul[,-ncol(simul$moy$simul)])
-   if (bloc==1) comp.simul$partiel$simul=cbind.data.frame(simul$moy$simul[,-ncol(simul$moy$simul)],as.factor(paste("P",bloc,"_",simul$moy$simul[,ncol(simul$moy$simul)],sep="")))
-   if (bloc!=1) comp.simul$partiel$simul=rbind.data.frame(comp.simul$partiel$simul, cbind.data.frame(simul$moy$simul[,-ncol(simul$moy$simul)],as.factor(paste("P",bloc,"_",simul$moy$simul[,ncol(simul$moy$simul)],sep=""))))
+   simul <- simulation(aa1, nbgroup = 1,nbsimul=nbsimul,nbchoix=nbchoix)
+   if (group==1) auxil = simul$moy$simul[,-ncol(simul$moy$simul)]
+   if (group!=1) auxil=cbind(auxil,simul$moy$simul[,-ncol(simul$moy$simul)])
+   if (group==1) comp.simul$partiel$simul=cbind.data.frame(simul$moy$simul[,-ncol(simul$moy$simul)],as.factor(paste("P",group,"_",simul$moy$simul[,ncol(simul$moy$simul)],sep="")))
+   if (group!=1) comp.simul$partiel$simul=rbind.data.frame(comp.simul$partiel$simul, cbind.data.frame(simul$moy$simul[,-ncol(simul$moy$simul)],as.factor(paste("P",group,"_",simul$moy$simul[,ncol(simul$moy$simul)],sep=""))))
  }
- 
-  eig =   cbind(resafmh$hmfa$eig,signif(resafmh$hmfa$eig/sum(resafmh$hmfa$eig)*100,4))
-  auxi= cbind.data.frame(resafmh$hmfa$li[,1:max(coord)],as.factor(indiv[1:nbprod,ncol(indiv)-1]),as.factor(rep(0,nbprod)))
-  colnames(auxi) = colnames(indiv)
-  plotpanelist(rbind.data.frame(auxi,indiv),eig=eig,color=color,coord=coord,name=name.panelist,cex=cex)
+
+ eig =   resafmh$eig
+ auxi= cbind.data.frame(resafmh$ind$coord[,1:max(coord)],as.factor(indiv[1:nbprod,ncol(indiv)-1]),as.factor(rep(0,nbprod)))
+ colnames(auxi) = colnames(indiv)
+ plotpanelist(rbind.data.frame(auxi,indiv),eig=signif(eig,4),color=color,coord=coord,name=name.panelist,cex=cex)
  comp.simul$moy$simul=auxil[,1:max(coord)]
- aux4=resafmh$coord.partial[[nivpanel]][[1]]
- for (bloc in 2:nbpanel) aux4=rbind(aux4,resafmh$coord.partial[[nivpanel]][[bloc]])
+ aux4=as.matrix(resafmh$partial[[nivpanel]][,,1])
+ for (group in 2:nbpanel) aux4=rbind(aux4,matrix(resafmh$partial[[nivpanel]][,,group],ncol=ncol(resafmh$partial[[nivpanel]]),dimnames=list(paste(rownames(resafmh$partial[[nivpanel]]),group,sep="."),colnames(resafmh$partial[[nivpanel]]))))
  for (ncoord in 1:max(coord))  comp.simul$moy$simul[,ncoord] = apply(auxil[,(max(coord)*(0:(nbpanel-1)))+ncoord],1,mean)
  comp.simul$moy$simul = cbind.data.frame(comp.simul$moy$simul,as.factor(simul$moy$simul[,ncol(comp.simul$partiel$simul)]))
- comp.simul$moy$P = cbind.data.frame(resafmh$hmfa$li[,1:max(coord)],rownames(resafmh$hmfa$li))
+ comp.simul$moy$P = cbind.data.frame(resafmh$ind$coord[,1:max(coord)],rownames(resafmh$ind$coord))
  comp.simul$partiel$P = cbind.data.frame(aux4[,1:max(coord)],rownames(aux4))
-
   if (nivpanel == length(hierar)){
   get(getOption("device"))(12,8)
-  plotellipse(comp.simul,alpha=alpha,eig=eig,coord=coord,color=color,cex=cex)  
+  plotellipse(comp.simul,alpha=alpha,eig=signif(eig,4),coord=coord,color=color,cex=cex)  
   if (length(names(donnee))==0) legend("bottomleft",legend=paste("Panel",1:nbpanel,sep=" "),lty=1:nbpanel,cex=0.8,bg="white")
   if (length(names(donnee))!=0) legend("bottomleft",legend=names(donnee),lty=1:nbpanel,cex=0.8,bg="white")
 }
 
   if (nivpanel < length(hierar)){
-
-    aux4=resafmh$coord.partial[[nivpanel+1]][[1]]
-    for (k in 2:length(resafmh$coord.partial[[nivpanel+1]])) aux4=rbind(aux4,resafmh$coord.partial[[nivpanel+1]][[k]])
+    aux4=resafmh$partial[[nivpanel+1]][,,1]
+    for (k in 2:dim(resafmh$partial[[nivpanel+1]])[3]) aux4=rbind(aux4,matrix(resafmh$partial[[nivpanel+1]][,,k],ncol=ncol(resafmh$partial[[nivpanel+1]]),dimnames=list(paste(rownames(resafmh$partial[[nivpanel+1]]),k,sep="."),colnames(resafmh$partial[[nivpanel+1]]))))
     comp.simul2 = list()
     comp.simul2$moy$P=comp.simul$moy$P
     comp.simul2$moy$simul=comp.simul$moy$simul
     comp.simul2$partiel$P = cbind.data.frame(aux4[,1:max(coord)],rownames(aux4))
-    for (k in 1:length(hierar[[nivpanel+1]])) {
+    for (k in 1:dim(resafmh$partial[[nivpanel+1]])[3]) {
       aux5 = array(NA,dim=c(nbprod*nbsimul,max(coord),hierar[[nivpanel+1]][k]))
       if (k==1) lim1 = 1
       if (k!=1) lim1 = sum(hierar[[nivpanel+1]][1:(k-1)])+1
@@ -212,24 +210,24 @@ for (bloc in 1:nbpanel){
     legend("bottomleft",legend=paste("Grouping panels",1:length(hierar[[nivpanel+1]]),sep=" "),lty=1:length(hierar[[nivpanel+1]]),cex=0.8,bg="white")
 
     get(getOption("device"))(12,8)
-    plotellipseinterhmfa(comp.simul,alpha=alpha,coord=coord,nbbloc=nbpanel,eig=eig,color=color,cex=cex,hmfa=list(hierar,resafmh$coord.partial))
+    plotellipseinterhmfa(comp.simul,alpha=alpha,coord=coord,nbgroup=nbpanel,eig=eig,color=color,cex=cex,hmfa=list(hierar,resafmh$partial))
     title(sub="Panels") 
     if (length(names(donnee))==0) legend("bottomleft",legend=paste("Panel",1:nbpanel,sep=" "),lty=1:nbpanel,cex=0.8,bg="white")
     if (length(names(donnee))!=0) legend("bottomleft",legend=names(donnee),lty=1:nbpanel,cex=0.8,bg="white")
   }
   mat = array(NA,dim=c(nbprod,nbprod,nbpanel+1))
-  for (bloc in 1:(nbpanel+1)){
-    if (bloc == (nbpanel+1)) aa = indiv
-    if (bloc !=(nbpanel+1)) aa = indiv[(nbprod*(sum(nbjuge[1:bloc])-nbjuge[bloc])):(nbprod*sum(nbjuge[1:bloc])),]
+  for (group in 1:(nbpanel+1)){
+    if (group == (nbpanel+1)) aa = indiv
+    if (group !=(nbpanel+1)) aa = indiv[(nbprod*(sum(nbjuge[1:group])-nbjuge[group])):(nbprod*sum(nbjuge[1:group])),]
     for (i in 1:(nbprod-1)){
       for (j in i:nbprod){
         if (length(nbchoix)==0){
-           if (bloc <(nbpanel+1)) mat[i,j,bloc] = mat[j,i,bloc] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbjuge[bloc],nbjuge[bloc])
-           if (bloc ==(nbpanel+1)) mat[i,j,bloc] = mat[j,i,bloc] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],sum(nbjuge),sum(nbjuge))
+           if (group <(nbpanel+1)) mat[i,j,group] = mat[j,i,group] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbjuge[group],nbjuge[group])
+           if (group ==(nbpanel+1)) mat[i,j,group] = mat[j,i,group] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],sum(nbjuge),sum(nbjuge))
         }
-        if (length(nbchoix)!=0) mat[i,j,bloc] = mat[j,i,bloc] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
+        if (length(nbchoix)!=0) mat[i,j,group] = mat[j,i,group] = hotelling(aa[aa[,ncol(aa)-1]==labprod[i],coord],aa[aa[,ncol(aa)-1]==labprod[j],coord],nbchoix,nbchoix)
     }}
-    for (i in 1:nbprod) mat[i,i,bloc]=1
+    for (i in 1:nbprod) mat[i,i,group]=1
   }
   if (length(names(donnee))==0) dimnames(mat)=list(labprod,labprod,c(paste("P",1:nbpanel,sep=""),"global"))
   if (length(names(donnee))!=0) dimnames(mat)=list(labprod,labprod,c(names(donnee),"global"))
